summaryrefslogtreecommitdiffstats
path: root/kio/kfile/kdiskfreesp.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kio/kfile/kdiskfreesp.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kio/kfile/kdiskfreesp.h')
-rw-r--r--kio/kfile/kdiskfreesp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/kfile/kdiskfreesp.h b/kio/kfile/kdiskfreesp.h
index 6a0591d6f..eeb285b08 100644
--- a/kio/kfile/kdiskfreesp.h
+++ b/kio/kfile/kdiskfreesp.h
@@ -34,10 +34,10 @@
class KProcess;
/**
* This class parses the output of "df" to find the disk usage
* information for a given partition (mount point).
*/
-class KIO_EXPORT KDiskFreeSp : public QObject
+class KIO_EXPORT KDiskFreeSp : public TQObject
{ Q_OBJECT
public:
KDiskFreeSp( TQObject *parent=0, const char *name=0 );
@@ -60,7 +60,7 @@ public:
* if this mount point is found, with the info requested.
* done is emitted in any case.
*/
- static KDiskFreeSp * findUsageInfo( const TQString & path );
+ static KDiskFreeSp * tqfindUsageInfo( const TQString & path );
signals:
void foundMountPoint( const TQString & mountPoint, unsigned long kBSize, unsigned long kBUsed, unsigned long kBAvail );
@@ -34,10 +34,10 @@
class KProcess;
/**
- * This class parses the output of "df" to find the disk usage
+ * This class parses the output of "df" to tqfind the disk usage
* information for a given partition (mount point).
*/